<!--
SPDX-FileCopyrightText: 2023 The eminus developers
SPDX-License-Identifier: Apache-2.0
-->
# psp

GTH pseudopotential file directory.

These pseudopotential files are copied from https://github.com/cp2k/cp2k-data for convenience but are identical to the pseudopotentials included in https://github.com/cp2k/cp2k. CP2K is licensed under the GPL-2.0 license.

| File | Description |
| :--: | :---------: |
| pade | LDA pseudopotential files |
| pbe  | PBE pseudopotential files |
